# Contributing to Zenplate

This is a small hobby project, but I'm open to contributions. Please feel free to report any issues or submit a pull request.

## Code of Conduct

Follow the rules (in no particular order):

1. Be inclusive. Everyone has a seat at the table, unless they can't get along with others.
2. Be respectful. Act without malice and treat others as you would like to be treated.
3. Be helpful. Criticism is welcome, but try to suggest a solution to the problem.
4. Be mindful. My an attempt at interpreting the words of others in the most positive light.

Transgressions of the rules above will be met with consequences (in order of most to least severe):

1. You will be ignored.
2. You will be asked to behave.
3. You won't be allowed to contribute.
4. I'll gossip about you with my friends, embellishing the story to make myself seem like a hero.
5. I'll send you the bill for my therapy sessions.
6. I'll pay a wizard to ensure that these transgressions echo in your mind, ceaseless like the wind, eventually culminating in a deep sense of regret and desire to be a better human.

The rules will be enforced arbitrarily by the maintainer. That means:

1. The maintainer is the final arbiter of what is acceptable.
2. The maintainer is not required to explain their decisions, but will likely entertain any questions.
3. You are not entitled to an appeal, but nothing is stopping you from trying.
4. The consequences listed above are not exhaustive, and the maintainer reserves the right to add more.
5. The consequences are chosen at the discretion of the maintainer. They may be applied in any order, or not at all.



## Things You Can Do

### Report a bug

If the behaviour of Zenplate is not as expected, please report it. 
Be sure to check the [existing issues](https://github.com/camratchford/zenplate/issues) to see if it has already been reported.
If there isn't already an issue matching your problem, please [open a new one](https://github.com/camratchford/zenplate/issues/new/choose)

### Suggest an enhancement

If you think something is missing from Zenplate, please let me know. 

### Write more tests

There's always room for more testing. If you opened a PR, please include tests for the new functionality or bug fix.

### Write an example

If you have a use case that you think would be a good example for Zenplate, please submit it.


### Write a plugin

If you have written a plugin that you think would be useful to others, please create an issue with the tag 'add-plugin' 
and I will list it in the docs.


### Tell people about it

If you think Zenplate is useful, please share it with others.